@@ -257,7 +257,7 @@ class Config(_ConfigBase):
     api_key = _ConfigValue("API_KEY")
     debug = _BoolConfigValue("DEBUG", default=False)
     server_url = _ConfigValue("SERVER_URL", default="https://ingress.hoss.com", required=True)
-    config_server_url = _ConfigValue("CONFIG_SERVER_URL", default="https://app.hoss.com", required=True)
+    config_server_url = _ConfigValue("CONFIG_SERVER_URL", default="https://app.hoss.com/api", required=True)
     server_cert = _ConfigValue("SERVER_CERT", default=None, required=False, validators=[FileIsReadableValidator()])
     verify_server_cert = _BoolConfigValue("VERIFY_SERVER_CERT", default=True)
     server_timeout = _ConfigValue(
@@ -268,7 +268,6 @@ class Config(_ConfigBase):
         ],
         default=10,
     )
-    hostname = _ConfigValue("HOSTNAME", default=socket.gethostname())
     transport_class = _ConfigValue("TRANSPORT_CLASS", default="hoss_agent.transport.http.AsyncTransport", required=True)
     processors = _ListConfigValue(
         "PROCESSORS",
