@@ -153,7 +153,7 @@ def sanitize_http_headers(client, api_config, event):
     headers_to_sanitize = []
     try:
         headers_to_sanitize = api_config[
-            "sanitized_headers"] if api_config is not None else client.client.config.account_api_configurations.get(
+            "sanitized_headers"] if api_config is not None else client.client.config.account_api_configuration.get(
             'sanitized_headers')
     except:
         pass
@@ -193,7 +193,7 @@ def sanitize_http_request_querystring(client, api_config, event):
         params_to_sanitize = []
         try:
             params_to_sanitize = api_config[
-                "sanitized_query_params"] if api_config is not None else client.client.config.account_api_configurations.get(
+                "sanitized_query_params"] if api_config is not None else client.client.config.account_api_configuration.get(
                 'sanitized_query_params')
         except:
             pass
@@ -205,7 +205,7 @@ def sanitize_http_request_querystring(client, api_config, event):
 
 def _do_sanitize_http_body(body, fields):
     if fields and body:
-        json_path_fields = map(lambda f: f['value'], filter(lambda f: f['type'] == 'JSONPath', fields))
+        json_path_fields = list(map(lambda f: f['value'], filter(lambda f: f['type'] == 'JSONPath', fields)))
         try:
             decoded_body = json.loads(body)
             return json.dumps(varmap(lambda k, v: _sanitize(k, v, json_path_fields), decoded_body)).encode('utf-8')
@@ -232,7 +232,7 @@ def sanitize_http_body(client, api_config, event):
     fields_to_sanitize = []
     try:
         fields_to_sanitize = api_config[
-            "sanitized_body_fields"] if api_config is not None else client.client.config.account_api_configurations.get(
+            "sanitized_body_fields"] if api_config is not None else client.client.config.account_api_configuration.get(
             'sanitized_body_fields')
     except Exception as e:
         logger.debug('Error getting sanitize configuration: %s', e)
