@@ -183,7 +183,7 @@ class Transport(ThreadManager):
             if isinstance(data['request']['body'], bytes):
                 data['request']['body'] = data['request']['body'].decode()
             elif hasattr(data['request']['body'], 'getvalue'):
-                data['request']['body'] = data['request']['body'].getvalue()
+                data['request']['body'] = data['request']['body'].getvalue().decode()
             else:
                 logger.debug('Cannot decode request body into string: %s. Removing it')
                 data['request']['body'] = None
@@ -195,7 +195,7 @@ class Transport(ThreadManager):
                 if isinstance(data['response']['body'], bytes):
                     data['response']['body'] = data['response']['body'].decode()
                 elif hasattr(data['response']['body'], 'getvalue'):
-                    data['response']['body'] = data['response']['body'].getvalue()
+                    data['response']['body'] = data['response']['body'].getvalue().decode()
                 else:
                     logger.debug('Cannot decode response body into string: %s. Removing it')
                     data['response']['body'] = None
